pub struct GpioReadResponse {
pub value: bool,
}Fields
value: boolTrait Implementations
Sourceimpl Clone for GpioReadResponse
impl Clone for GpioReadResponse
Sourcefn clone(&self) -> GpioReadResponse
fn clone(&self) -> GpioReadResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GpioReadResponse
impl Debug for GpioReadResponse
Sourceimpl<D: ResourceDialect> Decode<GpioReadResponse, D> for GpioReadResponse
impl<D: ResourceDialect> Decode<GpioReadResponse, D> for GpioReadResponse
Sourceimpl<D: ResourceDialect> Encode<GpioReadResponse, D> for &GpioReadResponse
impl<D: ResourceDialect> Encode<GpioReadResponse, D> for &GpioReadResponse
Sourceimpl<D: ResourceDialect, T0: Encode<bool, D>> Encode<GpioReadResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<bool, D>> Encode<GpioReadResponse, D> for (T0,)
Sourceimpl Hash for GpioReadResponse
impl Hash for GpioReadResponse
Sourceimpl Ord for GpioReadResponse
impl Ord for GpioReadResponse
Sourcefn cmp(&self, other: &GpioReadResponse) -> Ordering
fn cmp(&self, other: &GpioReadResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GpioReadResponse
impl PartialEq for GpioReadResponse
Sourcefn eq(&self, other: &GpioReadResponse) -> bool
fn eq(&self, other: &GpioReadResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for GpioReadResponse
impl PartialOrd for GpioReadResponse
Sourceimpl TypeMarker for GpioReadResponse
impl TypeMarker for GpioReadResponse
Sourcetype Owned = GpioReadResponse
type Owned = GpioReadResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for GpioReadResponse
impl ValueTypeMarker for GpioReadResponse
Sourcetype Borrowed<'a> = &'a GpioReadResponse
type Borrowed<'a> = &'a GpioReadResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Copy for GpioReadResponse
impl Eq for GpioReadResponse
impl Persistable for GpioReadResponse
impl StructuralPartialEq for GpioReadResponse