pub struct InterruptConfiguration {
pub mode: Option<InterruptMode>,
/* private fields */
}Fields
mode: Option<InterruptMode>Trait Implementations
Sourceimpl Clone for InterruptConfiguration
impl Clone for InterruptConfiguration
Sourcefn clone(&self) -> InterruptConfiguration
fn clone(&self) -> InterruptConfiguration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InterruptConfiguration
impl Debug for InterruptConfiguration
Sourceimpl<D: ResourceDialect> Decode<InterruptConfiguration, D> for InterruptConfiguration
impl<D: ResourceDialect> Decode<InterruptConfiguration, D> for InterruptConfiguration
Sourceimpl Default for InterruptConfiguration
impl Default for InterruptConfiguration
Sourcefn default() -> InterruptConfiguration
fn default() -> InterruptConfiguration
Returns the “default value” for a type. Read more
Sourceimpl<D: ResourceDialect> Encode<InterruptConfiguration, D> for &InterruptConfiguration
impl<D: ResourceDialect> Encode<InterruptConfiguration, D> for &InterruptConfiguration
Sourceimpl PartialEq for InterruptConfiguration
impl PartialEq for InterruptConfiguration
Sourcefn eq(&self, other: &InterruptConfiguration) -> bool
fn eq(&self, other: &InterruptConfiguration) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for InterruptConfiguration
impl TypeMarker for InterruptConfiguration
Sourcetype Owned = InterruptConfiguration
type Owned = InterruptConfiguration
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for InterruptConfiguration
impl ValueTypeMarker for InterruptConfiguration
Sourcetype Borrowed<'a> = &'a InterruptConfiguration
type Borrowed<'a> = &'a InterruptConfiguration
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Persistable for InterruptConfiguration
impl StructuralPartialEq for InterruptConfiguration